yt.analysis_modules.halo_finding.halo_objects.TextHalo.virial_mass — The yt Project 3.2-dev documentation

# yt.analysis_modules.halo_finding.halo_objects.TextHalo.virial_mass

`TextHalo.` `virial_mass`(*args, **kwargs)

  Return the virial mass of the halo in Msun, using only the particles in the halo (no baryonic information used).

  The virial mass is calculated, using the built in Halo.virial_info functionality. The mass is then returned.

  Parameters: | virial_overdensity : float The overdensity threshold compared to the universal average when calculating the virial mass. Default = 200. bins : int The number of spherical bins used to calculate overdensities. Default = 300.
  Returns: | mass : float The virial mass in solar masses of the particles in the halo. -1 if not virialized.

  Examples

      >>> vm = halos[0].virial_mass()